@@ -53,7 +53,11 @@
 #include <QHeaderView>
 #include <QMenu>
 #include <QAction>
-#include <QDesktopWidget>
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 10, 0))
+#	include <QScreen>
+#else
+#	include <QDesktopWidget>
+#endif
 #include <QShortcut>
 #include <QDateTimeEdit>
 
@@ -318,8 +322,18 @@ LedgerDialog::LedgerDialog(AssetsAccount *acc, Budget *budg, Eqonomize *parent,
 	setColumnMoneyWidth(transactionsView, 11, budget, 999999999.99);
 	min_width_1 = transactionsView->columnWidth(0) + transactionsView->columnWidth(1) + transactionsView->columnWidth(2) + transactionsView->columnWidth(3) + transactionsView->columnWidth(4) + transactionsView->columnWidth(9) + transactionsView->columnWidth(10) + transactionsView->columnWidth(11) + 30;
 	min_width_2 = min_width_1 + transactionsView->columnWidth(8);
-	QDesktopWidget desktop;
-	if(desktop.availableGeometry(this).width() > min_width_1 * 1.2) transactionsView->setMinimumWidth(min_width_1);
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 10, 0))
+#	if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+	QScreen *scr = screen();
+#	else
+	QScreen *scr = QGuiApplication::screenAt(pos);
+#	endif
+	if(!scr) scr = QGuiApplication::primaryScreen();
+	QRect rect = scr->availableGeometry();
+#else
+	QRect rect = QApplication::desktop()->availableGeometry(this);
+#endif
+	if(rect.width() > min_width_1 * 1.2) transactionsView->setMinimumWidth(min_width_1);
 	transactionsView->setColumnHidden(5, true);
 	transactionsView->setColumnHidden(6, true);
 	transactionsView->setColumnHidden(7, true);
@@ -436,7 +450,11 @@ void LedgerDialog::keyPressEvent(QKeyEvent *e) {
 	if(e == key_event) return;
 	QDialog::keyPressEvent(e);
 	if(!e->isAccepted() && !transactionsView->hasFocus()) {
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+		key_event = new QKeyEvent(e->type(), e->key(), e->modifiers(), e->nativeScanCode(), e->nativeVirtualKey(), e->nativeModifiers(), e->text(), e->isAutoRepeat(), e->count());
+#else
 		key_event = new QKeyEvent(*e);
+#endif
 		QApplication::sendEvent(transactionsView, key_event);
 		delete key_event;
 	}
@@ -790,6 +808,7 @@ void LedgerDialog::popupHeaderMenu(const QPoint &p) {
 
 void LedgerDialog::ascendingToggled(bool b) {
 	b_ascending = b;
+	transactionsView->verticalScrollBar()->setValue(0);
 	updateTransactions();
 }
 
@@ -809,10 +828,21 @@ void LedgerDialog::accountChanged() {
 	if(!account) return;
 	bool b_loan = (account->accountType() == ASSETS_TYPE_LIABILITIES || account->accountType() == ASSETS_TYPE_CREDIT_CARD);
 	transactionsView->setColumnHidden(8, !b_loan);
-	QDesktopWidget desktop;
-	if(desktop.availableGeometry(this).width() > min_width_2 * 1.2) transactionsView->setMinimumWidth(b_loan ? min_width_2 : min_width_1);
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 10, 0))
+#	if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+	QScreen *scr = screen();
+#	else
+	QScreen *scr = QGuiApplication::screenAt(pos);
+#	endif
+	if(!scr) scr = QGuiApplication::primaryScreen();
+	QRect rect = scr->availableGeometry();
+#else
+	QRect rect = QApplication::desktop()->availableGeometry(this);
+#endif
+	if(rect.width() > min_width_2 * 1.2) transactionsView->setMinimumWidth(b_loan ? min_width_2 : min_width_1);
 	ActionNewDebtInterest->setVisible(b_loan);
 	ActionNewDebtPayment->setVisible(b_loan);
+	transactionsView->verticalScrollBar()->setValue(0);
 	updateTransactions(true);
 	reconcileOpeningEdit->setCurrency(account->currency());
 	reconcileChangeEdit->setCurrency(account->currency());
@@ -903,7 +933,9 @@ void LedgerDialog::onFilterSelected(QString filter) {
 bool LedgerDialog::exportList(QTextStream &outf, int fileformat, QDate first_date, QDate last_date) {
 	switch(fileformat) {
 		case 'h': {
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
 			outf.setCodec("UTF-8");
+#endif
 			outf << "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">" << '\n';
 			outf << "<html>" << '\n';
 			outf << "\t<head>" << '\n';
@@ -1027,7 +1059,9 @@ void LedgerDialog::printView() {
 		QDateEdit *dateToEdit = new EqonomizeDateEdit(QDate::currentDate(), dialog);
 		dateToEdit->setCalendarPopup(true);
 		grid->addWidget(dateToEdit, 1, 1);
-		QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+		QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Cancel | QDialogButtonBox::Ok, Qt::Horizontal, dialog);
+		buttonBox->button(QDialogButtonBox::Ok)->setDefault(true);
+		buttonBox->button(QDialogButtonBox::Cancel)->setAutoDefault(false);
 		buttonBox->button(QDialogButtonBox::Ok)->setShortcut(Qt::CTRL | Qt::Key_Return);
 		connect(buttonBox->button(QDialogButtonBox::Cancel), SIGNAL(clicked()), dialog, SLOT(reject()));
 		connect(buttonBox->button(QDialogButtonBox::Ok), SIGNAL(clicked()), dialog, SLOT(accept()));
@@ -1152,6 +1186,10 @@ void LedgerDialog::transactionSelectionChanged() {
 			b_clone = false;
 			break;
 		} else {
+			if((b_join || b_edit) && trans->subtype() == TRANSACTION_SUBTYPE_REINVESTED_DIVIDEND) {
+				b_join = false;
+				if(index > 0 || selection.size() > 1) b_edit = false;
+			}
 			if(b_edit && trans->parentSplit() && (index > 0 || selection.size() > 1)) b_edit = false;
 			if(b_split) {
 				if(!split) split = trans->parentSplit();
@@ -1441,6 +1479,8 @@ void LedgerDialog::edit(QTreeWidgetItem *qwi, int c) {
 	}
 }
 void LedgerDialog::updateTransactions(bool update_reconciliation_date) {
+	expenseColor = QColor();
+	incomeColor = QColor();
 	int scroll_h = transactionsView->horizontalScrollBar()->value();
 	int scroll_v = transactionsView->verticalScrollBar()->value();
 	Transaction *selected_transaction = NULL;
@@ -1451,6 +1491,7 @@ void LedgerDialog::updateTransactions(bool update_reconciliation_date) {
 		selected_split = i->splitTransaction();
 		if(!selected_split) selected_transaction = i->transaction();
 	}
+	int scrollpos = transactionsView->verticalScrollBar()->value();
 	transactionsView->clear();
 	double balance = account->initialBalance();
 	double total_balance = 0.0;
@@ -1480,6 +1521,7 @@ void LedgerDialog::updateTransactions(bool update_reconciliation_date) {
 	QVector<SplitTransaction*> splits;
 	bool last_reconciled = true;
 	QDate rec_date, first_date;
+	LedgerListViewItem *selected_item = NULL;
 	while(transs) {
 		if(transs == split) {
 			if(split->type() == SPLIT_TRANSACTION_TYPE_MULTIPLE_ITEMS && ((MultiItemTransaction*) split)->account() == account) {
@@ -1503,7 +1545,7 @@ void LedgerDialog::updateTransactions(bool update_reconciliation_date) {
 				}
 				quantity++;
 				if(split == selected_split) {
-					i->setSelected(true);
+					selected_item = i;
 				}
 				if(!split->associatedFile().isEmpty()) i->setIcon(value >= 0 ? 9 : 10, LOAD_ICON_STATUS("mail-attachment"));
 			} else if(split->type() == SPLIT_TRANSACTION_TYPE_LOAN) {
@@ -1529,7 +1571,7 @@ void LedgerDialog::updateTransactions(bool update_reconciliation_date) {
 							last_reconciled = false;
 						}
 						if(ltrans == selected_transaction) {
-							i->setSelected(true);
+							selected_item = i;
 						}
 						quantity++;
 						if(!split->associatedFile().isEmpty()) i->setIcon(value >= 0 ? 9 : 10, LOAD_ICON_STATUS("mail-attachment"));
@@ -1559,7 +1601,7 @@ void LedgerDialog::updateTransactions(bool update_reconciliation_date) {
 							last_reconciled = false;
 						}
 						if(ltrans == selected_transaction) {
-							i->setSelected(true);
+							selected_item = i;
 						}
 						if(!split->associatedFile().isEmpty()) i->setIcon(to_balance ? (value >= 0.0 ? 10 : 9) : 8, LOAD_ICON_STATUS("mail-attachment"));
 					}
@@ -1588,7 +1630,7 @@ void LedgerDialog::updateTransactions(bool update_reconciliation_date) {
 							last_reconciled = false;
 						}
 						if(ltrans == selected_transaction) {
-							i->setSelected(true);
+							selected_item = i;
 						}
 						if(!split->associatedFile().isEmpty()) i->setIcon(to_balance ? (value >= 0.0 ? 10 : 9) : 8, LOAD_ICON_STATUS("mail-attachment"));
 					}
@@ -1616,7 +1658,7 @@ void LedgerDialog::updateTransactions(bool update_reconciliation_date) {
 						}
 						quantity++;
 						if(split == selected_split) {
-							i->setSelected(true);
+							selected_item = i;
 						}
 						if(!split->associatedFile().isEmpty()) i->setIcon(value >= 0 ? 9 : 10, LOAD_ICON_STATUS("mail-attachment"));
 					}
@@ -1648,7 +1690,7 @@ void LedgerDialog::updateTransactions(bool update_reconciliation_date) {
 				i->setText(2, tr("Transfer"));
 			}
 			if(trans == selected_transaction) {
-				i->setSelected(true);
+				selected_item = i;
 			}
 			i->d_balance = balance;
 			if(trans->isReconciled(account)) {
@@ -1678,6 +1720,13 @@ void LedgerDialog::updateTransactions(bool update_reconciliation_date) {
 		if(!transs || (split && (split->date() < trans->date() || (split->date() == trans->date() && split->timestamp() < trans->timestamp())))) transs = split;
 	}
 
+	if(!update_reconciliation_date) transactionsView->verticalScrollBar()->setValue(scrollpos);
+	if(selected_item) {
+		selected_item->setSelected(true);
+		transactionsView->setCurrentItem(selected_item);
+		transactionsView->scrollToItem(selected_item);
+	}
+
 	if(previous_date.isValid() && previous_date < QDate::currentDate()) previous_balance *= previous_date.daysTo(QDate::currentDate());
 	total_balance += previous_balance;
 	if(first_date.isValid() && first_date < QDate::currentDate()) total_balance /= (first_date.daysTo(QDate::currentDate()) + (previous_date == QDate::currentDate() ? 1 : 0));
@@ -1702,6 +1751,9 @@ void LedgerDialog::updateTransactions(bool update_reconciliation_date) {
 		reconcileStartEdit->setDate(rec_date);
 		reconcileStartEdit->blockSignals(false);
 	}
+	labelExpenseColor = QColor();
+	labelIncomeColor = QColor();
+	labelTransferColor = QColor();
 	if(b_reconciling) updateReconciliationStats(false, true, true);
 }
 void LedgerDialog::reject() {
