@@ -505,7 +505,9 @@ ExportQIFDialog::ExportQIFDialog(Budget *budg, QWidget *parent, bool extra_param
 	layouth->addWidget(fileButton);
 	grid->addLayout(layouth, 3, 1);
 
-	buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+	buttonBox = new QDialogButtonBox(QDialogButtonBox::Cancel | QDialogButtonBox::Ok, Qt::Horizontal, this);
+	buttonBox->button(QDialogButtonBox::Ok)->setDefault(true);
+	buttonBox->button(QDialogButtonBox::Cancel)->setAutoDefault(false);
 	buttonBox->button(QDialogButtonBox::Cancel)->setShortcut(Qt::CTRL | Qt::Key_Return);
 	buttonBox->button(QDialogButtonBox::Ok)->setEnabled(false);
 	connect(buttonBox->button(QDialogButtonBox::Cancel), SIGNAL(clicked()), this, SLOT(reject()));
@@ -621,21 +623,28 @@ void testQIFDate(const QString &str, bool &p1, bool &p2, bool &p3, bool &p4, boo
 			}
 		}
 		if(separator < 0) separator = 0;
-		p1 = (separator != 0);
-		p2 = (separator != 0);
+		p1 = (separator != 0 || str.length() == 6);
+		p2 = (separator != 0 || str.length() == 6);
 		p3 = true;
-		p4 = (separator != 0);
-		ly = false;
+		p4 = (separator != 0 || str.length() == 6);
+		ly = (separator == 0 && str.length() >= 8);
 	}
 	if(p1 + p2 + p3 + p4 <= 1) {
 		lz = 1;
 		return;
 	}
+	QStringList strlist;
+	if(separator == 0) {
+		strlist << str.left(2);
+		strlist << str.mid(2, 2);
+		strlist << str.right(2);
+	} else {
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
-	QStringList strlist = str.split(separator, Qt::SkipEmptyParts);
+		strlist = str.split(separator, Qt::SkipEmptyParts);
 #else
-	QStringList strlist = str.split(separator, QString::SkipEmptyParts);
+		strlist = str.split(separator, QString::SkipEmptyParts);
 #endif
+	}
 	if(strlist.count() == 2 && (p1 || p2)) {
 		int i = strlist[1].indexOf('\'');
 		if(i >= 0) {
@@ -1506,7 +1515,7 @@ void importQIF(QTextStream &fstream, bool test, qif_info &qi, Budget *budget, bo
 
 QString writeQIFDate(const QDate &date, int date_format) {
 	if(date_format == 1) return date.toString(Qt::ISODate);
-	else if(date_format == 2) return date.toString(Qt::LocalDate);
+	else if(date_format == 2) return QLocale().toString(date, QLocale::ShortFormat);
 	if(date.year() >= 2000) return date.toString("MM/dd'yy");
 	return date.toString("MM/dd/yy");
 }
